package batteryRows;

# {{{ modules
use Moose;

use Node;
use HTML::Template;
use Data::Dumper;
use Spreadsheet::ParseExcel;
use batteryRow;
# }}}

sub  read_xls
# {{{
{
      my $self = shift;
      my $file_name = shift;

      my $parser   = Spreadsheet::ParseExcel->new();
      my $workbook = $parser->parse($file_name);

      unless( defined $workbook ) {
            die $parser->error(), ".\n";
      }

      my @worksheets = $workbook->worksheets();
      my $worksheet = $worksheets[0];

      # {{{ read header from the 1' cell
      my $header = new Node;
      $header->{name} = "1";
      $header->set_type("header");

      my $cell = $worksheet->get_cell( 0, 0 );
      $header->set_caption($cell->value());
      $self->{header} = $header;
      # }}}

      my ( $row_min, $row_max ) = $worksheet->row_range();
      my ( $col_min, $col_max ) = $worksheet->col_range();

      for (my $i = 1; $i <= $row_max; ++$i) {

            my $row_ref = read_row($worksheet, $col_max, $i);
            my $batteryRow = new batteryRow("captions" => $row_ref, "number" => $i);
            push(@{$self->{rows}}, $batteryRow);
      }
}
# }}}

sub  read_row
# {{{
{
      my $worksheet = shift;
      my $col_max = shift;
      my $row = shift;

      my @output;
      for (my $i = 0; $i <= $col_max; ++$i) {
            my $cell = $worksheet->get_cell( $row, $i );
            $cell = $cell->value();
            $cell =~ s/\\/\\/;

            push(@output, $cell);
      }

      return \@output;
}
# }}}

sub  output
# {{{
{
      my $self = shift;

      my $template = new HTML::Template(
            "filename" => qq{./tmpl/battery.tmpl},
            "loop_context_vars" => 1,
            "die_on_bad_params" => 0
        );

      my $header_text_ref = $self->{header}->output();

      my $i = 1;
      my $rows;
      my $lines;
      foreach( @{$self->{rows}})
      {
            my $text_ref = $_->output();
            $rows .= $$text_ref;
            $lines .= $_->{lines};

            if ($i > 1) {
                  my $prev_row = $i - 1;
                  $lines .= "\\draw [line] (".$prev_row.'_0.west) --++ (-5mm, 0) |- ('.$i."_0.west);";
            }
            ++$i;
      }

      $template->param(
            "header" => $$header_text_ref,
            "rows" => $rows,
            "lines" => $lines,
        );
      my $output = $template->output();
      return \$output;
}
# }}}

no Moose;
__PACKAGE__->meta->make_immutable;
